@@ -21,8 +21,7 @@ MAC_FILE::MAC_FILE()
     m_nRetVal = ERROR_UNDEFINED;
     m_bStarted = false;
     m_bNeedsUpdate = false;
-    m_dwStartTickCount = 0;
-    m_dwEndTickCount = 0;
+    m_nProcessingElapsed = 0;
     m_nLevel = 0;
     m_nKillFlag = 0;
     m_nCurrentStage = 0;
@@ -42,8 +41,7 @@ bool MAC_FILE::PrepareForProcessing(CMACProcessFiles * pProcessFiles)
     m_nRetVal = ERROR_UNDEFINED;
     m_bStarted = false;
     m_bNeedsUpdate = false;
-    m_dwStartTickCount = 0;
-    m_dwEndTickCount = 0;
+    m_nProcessingElapsed = 0;
     m_strFormat = theApp.GetSettings()->GetFormat();
     m_nLevel = theApp.GetSettings()->GetLevel();
     m_nKillFlag = KILL_FLAG_CONTINUE;
