@@ -8,11 +8,10 @@ class CWinampSettingsDlg : public CDialog
     DECLARE_DYNAMIC(CWinampSettingsDlg)
 
 public:
-
-    CWinampSettingsDlg(CWnd * pParent = NULL);
+    CWinampSettingsDlg(CWnd * pParent = APE_NULL);
     virtual ~CWinampSettingsDlg();
 
-    BOOL Show(HWND hwndParent);
+    bool Show(HWND hwndParent);
 
     virtual BOOL OnInitDialog();
     enum { IDD = IDD_WINAMP_SETTINGS };
@@ -24,7 +23,6 @@ public:
     int m_nThreadPriority;
 
 protected:
-
     virtual void DoDataExchange(CDataExchange * pDX);
     virtual void OnOK();
     DECLARE_MESSAGE_MAP()
@@ -33,8 +31,8 @@ protected:
     HWND m_hwndParent;
 
     CString m_strSettingsFilename;
-    BOOL LoadSettings();
-    BOOL SaveSettings();
+    bool LoadSettings();
+    bool SaveSettings();
     int GetSliderFromThreadPriority();
     int GetThreadPriorityFromSlider();
 };
